@@ -1,9 +1,6 @@
 #!/usr/bin/python
 import os
 import sys,time,re
-try:
-	import osso
-except: print "Not N900"
 import webbrowser
 from PyQt4 import QtGui,QtCore
 from PyQt4.QtCore import *
@@ -12,7 +9,7 @@ from pyRadio_ui import *
 from pyRadio_ui_portrait import *
 from radioplayer import RadioPlayer
 
-import gobject, dbus
+import dbus
 from dbus.mainloop.glib import DBusGMainLoop
 
 __title__ = "Pandora"
@@ -98,11 +95,21 @@ class Panda(QtGui.QMainWindow):
 		self.pui = None
 		self.ui = Ui_pyRadio()
 		self.ui.setupUi(self)
+		self.portrait = False
+		self.os = self.player.get_product()
+		if self.os != "RX-51":
+			self.ui.albumArt.setStyleSheet("background-color: rgb(255, 255, 255);")
+
 		if not self.c.lastplayed == "":
 			self.player.playStation = self.c.lastplayed
 		try :
 			self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
 			self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged );
+			screenGeometry=QApplication.desktop().screenGeometry();
+			if screenGeometry.width() > screenGeometry.height():
+				self.portrait = False
+			else:
+				self.portrait = True
 			print" Auto rotation on"
 		except:print "could not autorotate on"
 		self.skip = 0
@@ -169,7 +176,8 @@ class Panda(QtGui.QMainWindow):
 		QtCore.QObject.connect(self.player,QtCore.SIGNAL("authSuccess"), self.sigAuth)
 		QtCore.QObject.connect(self.player,QtCore.SIGNAL("authFail"), self.sigAuth)
 		QtCore.QObject.connect(self.player,QtCore.SIGNAL("stationCreated"), self.stationCreated)
-		QtCore.QObject.connect(self.s, QtCore.SIGNAL('shutdown'), self.sQuit)
+		QtCore.QObject.connect(self.player,QtCore.SIGNAL("duration"), self.setDuration)
+		QtCore.QObject.connect(self.s, QtCore.SIGNAL('shutdown'), self.closeEvent)
 		QtCore.QObject.connect(self.ui.actionUser_Pass, QtCore.SIGNAL('triggered()'), self.setUserPass)
 		QtCore.QObject.connect(self.ui.actionDelete, QtCore.SIGNAL('triggered()'), self.deleteStation)
 		QtCore.QObject.connect(self.ui.actionEnable_FM_Radio, QtCore.SIGNAL('triggered()'), self.doFM)
@@ -180,10 +188,11 @@ class Panda(QtGui.QMainWindow):
 	def open_donate( self ):
 		self.d = QDialog(self)
 		self.d.setParent(self)
-		if not self.portrait:
-			self.d.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
-		else:
-			self.d.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
+		if self.os == "RX-51":
+			if not self.portrait:
+				self.d.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
+			else:
+				self.d.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
 		vbox = QVBoxLayout()
 		hLayout = QHBoxLayout()
 		m = QPushButton("pyRadio")
@@ -211,10 +220,20 @@ class Panda(QtGui.QMainWindow):
 		self.ui.listStations.clear()
 		self.player.getStatlist = 1
 	
+	def setDuration( self ):
+		if (self.player.duration-self.player.position) < self.player.duration:
+			position = "%02d:%02d" % divmod(self.player.duration - self.player.position, 60) + " / " + "%02d:%02d" % divmod(self.player.duration, 60)
+			self.ui.lblTime.setText(position)
+
 	def createStation( self ):
-		self.ui.albumArt.setHtml("Please wait..... ")
+		if self.os == "RX-51":
+			if not self.portrait:
+				self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
+			else:
+				self.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
 		station, ok = QtGui.QInputDialog.getText(self,"Artist or Track Name", "Enter an Artist or Track Name:")
 		if len(station)>0:
+			self.ui.albumArt.setHtml("Please wait..... ")
 			ret = self.player.search(station)
 			if len(ret["artists"])>0 or len(ret["songs"])>0:
 				if len(ret["artists"])>0 and len(ret["songs"])>0:
@@ -237,8 +256,9 @@ class Panda(QtGui.QMainWindow):
 				for s in songs:
 					self.ui.listStations.addItem(s[title])
 					self.createStations = songs
-
 			ok = QtGui.QMessageBox.warning(self,'Select Match','Select the closest title from the station drop down.')
+		if self.os == "RX-51":
+			self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
 
 	def stationDeleted( self ):
 		ok = QtGui.QMessageBox.warning(self, "Station Deleted", "Station Deleted.")
@@ -248,6 +268,11 @@ class Panda(QtGui.QMainWindow):
 		self.skipSong()
 
 	def deleteStation(self):
+		if self.os == "RX-51":
+			if not self.portrait:
+				self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
+			else:
+				self.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
 		reply = QtGui.QMessageBox.question(self, 'Delete Station',
 			"Really delete "+self.ui.listStations.currentText()+"?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
 		if reply == QtGui.QMessageBox.Yes:
@@ -255,6 +280,8 @@ class Panda(QtGui.QMainWindow):
 			self.player.stopPlayBack()
 			self.player.deleteStation = 1
 			self.ui.albumArt.setHtml("Please wait...")
+		if self.os == "RX-51":
+			self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
 
 	def tiredSong(self):
 		check = QtGui.QMessageBox.question(self, 'Are you sure?', 'Are you tired of the song ' + self.player.curSong[1]["title"] + '?','No','Yes')
@@ -262,11 +289,18 @@ class Panda(QtGui.QMainWindow):
 			self.player.tiredSong = 1
 
 	def setSnooze(self):
+		if self.os == "RX-51":
+			if not self.portrait:
+				self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
+			else:
+				self.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
 		ktime,ok = QtGui.QInputDialog.getText(self,"Snooze", "Enter a time, in minutes, to shutdown:")
 		if ok:
 			self.s.cont = 1
 			self.s.ktime = int(ktime)
 			self.s.start()
+		if self.os == "RX-51":
+			self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
 
 	def doFM(self):
 		state = self.fmtx_iface.Get("com.nokia.FMTx.Device", "state")
@@ -288,10 +322,14 @@ class Panda(QtGui.QMainWindow):
 			self.player.stopPlayBack('pause')
 			self.player.playing = 0
 			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/paused-trans.png);")
-		else:
+		elif self.player.playlist != []:
 			self.player.startPlayBack()
 			self.player.playing = 1
 			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/playing-trans.png);")
+		else:
+			self.playStation()
+			self.player.playing = 1
+			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/playing-trans.png);")
 
 	def doLove( self ):
 		self.player.loveHateRating = True
@@ -329,8 +367,13 @@ class Panda(QtGui.QMainWindow):
 			self.auth()
 
 	def auth( self ):
+		if self.os == "RX-51":
+			if not self.portrait:
+				self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
+			else:
+				self.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
 		if self.count>2:
-			self.sQuit()
+			self.closeEvent()
 		self.count += 1
 		if self.c.user == "":
 			self.c.user,ok = QtGui.QInputDialog.getText(self,"Username", "Pandora Username:", QLineEdit.Normal)
@@ -344,6 +387,8 @@ class Panda(QtGui.QMainWindow):
 		self.player.doAuth = 1
 		self.authenticated = True
 		self.c.write()
+		if self.os == "RX-51":
+			self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
 
 	def playStation( self ):
 		if len(self.createStations)>0:
@@ -442,12 +487,13 @@ class Panda(QtGui.QMainWindow):
 	def stop( self ):
 		self.player.playing = False
 
-	def sQuit( self ):
+	def closeEvent(self, event=None):
 		self.player.skip = False
 		if self.player.playing:
 			self.player.playing = False
 			self.player.stopPlayBack()
 		self.player.run = 0
+		self.player.close()
 		del self.ui
 		del self.player
 		quit()
