@@ -1,10 +1,5 @@
-import gobject, sys, time
+import sys, time
 
-import pygst
-pygst.require('0.10')
-import gst
-
-from libpiano.pulse_calls import *
 from libpiano.pandora import Pandora
 from PyQt4 import QtCore
 
@@ -13,7 +8,7 @@ class PandaException( Exception ):
 
 class RadioPlayer(QtCore.QThread):
 	__pyqtSignals__ = ( "PlayNext", "LoveHate", "songs", "stations", "deleted", "tired", "authSuccess", \
-		"stationCreated", "authFail" )
+		"stationCreated", "authFail", "duration" )
 	
 	def __init__( self, Parent=None ):
 		self.timer = None
@@ -23,6 +18,8 @@ class RadioPlayer(QtCore.QThread):
 		self.user = ""
 		self.password = ""
 		self.success = 0
+		self.duration = 0
+		self.position = 0
 
 		self.getStatlist = 0
 		self.getPlaylist = 0
@@ -35,6 +32,16 @@ class RadioPlayer(QtCore.QThread):
 		self.doAuth = 0
 		self.createStationId = 0
 		
+		self.os = self.get_product()
+		if self.os == "RX-51":
+			from libpiano.MAFWBackend import MAFWBackend
+			self.player = MAFWBackend()
+		else:
+			from libpiano.OSSOBackend import OSSOBackend
+			self.player = OSSOBackend()
+		QtCore.QObject.connect(self.player, QtCore.SIGNAL("eof"), self.onPlayBackEnded)
+		QtCore.QObject.connect(self.player, QtCore.SIGNAL("pos_changed(int,int)"), self.updateTime)
+		self.stop = True
 		self.playStation = 0
 		self.stations = []
 		self.curStation = ""
@@ -47,23 +54,6 @@ class RadioPlayer(QtCore.QThread):
 
 	def run(self):
 		self.pandora.sync()
-		self.player = gst.element_factory_make("playbin2", "player")
-		fakesink = gst.element_factory_make("fakesink", "fakesink")
-		pulsesink = gst.element_factory_make("pulsesink", "pulsesink")
-		proplist = pa_proplist_new()
-		pa_proplist_sets (proplist, "event.id", "ringtone-preview")
-		g_object_set(c_void_p(hash(pulsesink)), "proplist", proplist, None)
-		pulsesink.set_property("buffer-time", 512000)
-		self.player.set_property("audio-sink", pulsesink)
-		self.player.set_property("video-sink", fakesink)
-		self.player.set_property("buffer-size", 512000)
-		bus = self.player.get_bus()
-		bus.add_signal_watch()
-		bus.connect("message::eos", self.onPlayBackEnded)
-		#bus.connect("message", self.on_message)
-		loop = gobject.MainLoop()
-		gobject.threads_init()
-		context = loop.get_context()
 		while self.run:
 			if self.loveHateSong:
 				self.loveHateSong = 0
@@ -93,6 +83,30 @@ class RadioPlayer(QtCore.QThread):
 
 			time.sleep ( 0.5 )
 
+	def get_product( self ):
+		try:                                                               
+			lines = open("/proc/component_version", "r").readlines()       
+		except:                                                            
+			lines = []                                                     
+			                                           
+		product = "?"                                                      
+		for line in lines:                                                 
+			line = line.strip()                                            
+			if (line.startswith("product")):                               
+				parts = line.split()                                       
+				product = parts[1].strip()                                 
+				break                                                      
+		#end for
+		return product
+
+	def updateTime( self, pos, total ):
+		if self.playing:
+			self.position = pos
+			self.duration = total
+			#print "%02d:%02d" % divmod(self.duration[1], 60)
+			if self.duration > 0:
+				self.emit(QtCore.SIGNAL("duration"))
+
 	def createStation( self ):
 		ret = self.pandora.createStation( self.createStationId )
 		self.playStation = ret["stationId"]
@@ -116,36 +130,30 @@ class RadioPlayer(QtCore.QThread):
 		self.play( item[0], item[1] )
 
 	def play( self, url, item ):
-		self.player.set_property('uri', url)
-		time.sleep ( 0.5 )
-		self.player.set_state(gst.STATE_PLAYING)
+		time.sleep( 0.5 )
+		self.player.load_audio(url)
 
 	def stopPlayBack ( self,state=None ):
 		if state == 'pause':
-			self.player.set_state(gst.STATE_PAUSED)
+			self.player.pause()
 		else:
-			self.player.set_state(gst.STATE_NULL)
+			self.player.stop()
 			if self.skip:
 				self.onPlayBackStopped()
 	
 	def startPlayBack ( self ):
-		self.player.set_state(gst.STATE_PLAYING)
+		self.player.play()
 
 	def onPlayBackStopped( self ):
 		if self.playing:
 			if self.skip:
-				self.player.set_state(gst.STATE_NULL)
-				time.sleep ( 0.5 )
 				self.skip = False
 				self.emit(QtCore.SIGNAL("PlayNext"))
 
-	def onPlayBackEnded( self, bus, msg ):
-		if self.playing:
-			if self.skip:
-				self.skip = False
-			self.player.set_state(gst.STATE_NULL)
-			time.sleep ( 0.5 )
-			self.emit(QtCore.SIGNAL("PlayNext"))
+	def onPlayBackEnded( self ):
+		if self.skip:
+			self.skip = False
+		self.emit(QtCore.SIGNAL("PlayNext"))
 
 	def LoveHate( self ):
 		self.respLH = self.pandora.addFeedback( self.curSong[1]["stationId"], self.curSong, self.loveHateRating )
@@ -190,7 +198,9 @@ class RadioPlayer(QtCore.QThread):
 			"musicId"	: s["musicId"] }
 			items.append( ( s["audioURL"], item ) )
 		self.playlist.extend( items )
-	
-	def on_message( self, bus, msg ):
-		#print msg
-		return
+
+	def close( self ):
+		self.player.stop()
+		self.player.close()
+		self.player = None
+		time.sleep( 1 )
